#---------------------------------------------------------------------------
# Name: 	definitionQuery_MapProduction.py
# Purpose: 	to create species maps automatically through definition queries
#
# Author: 	Laura Blackburn, GISP
#
# Created: 	8/26/2016, roughly 3 hrs
# Copyright:	(c) LMB 2016
#
#---------------------------------------------------------------------------

# 1. Import modules and set environment
import arcpy, os, sys
from arcpy import env

env.workspace = r"F:\Workspace\AFPE\NRS03_AFPE.gdb"
path = 'F:\\Workspace\\AFPE\\2016\\RawMaps2\\'


# 2. Open a map document - F:\Workspace\AFPE\2016\RawMaps\test.mxd
mxd = arcpy.mapping.MapDocument(r"F:\Workspace\AFPE\2016\RawMaps2\test.mxd")
df = arcpy.mapping.ListDataFrames(mxd)[0]

# 3. Open the lookup table - NRS_03AFPELookup
LUTname = "NRS03_AFPElookup"

try:
        # 4. use a cursor to loop through each row in the DCA field and store as variable
        DCAcursor = arcpy.da.SearchCursor(LUTname, ["DCA"])
        for row in DCAcursor:
                DCAstr = str(row[0])
                DCAint = (row[0])
                print "DCA: " + DCAstr

        # 5. grap USACounty and USAState layers and perform definition query w/ above DCA variable
        #----USAState definition query will have a dozen or so empty queries -w/o throwing an error
                layers = arcpy.mapping.ListLayers(mxd,"USA*",df)
                print layers[0].definitionQuery
                print layers[1].definitionQuery

                cntLyr = layers[0]
                stLyr = layers[1]

                query1 = '"CountyReport$.DCA"=' + DCAstr
                query2 = '"StateReport$.DCA"='+ DCAstr


                cntLyr.definitionQuery = query1
                stLyr.definitionQuery = query2

                print cntLyr.definitionQuery
                print stLyr.definitionQuery
                newMap = path + DCAstr
                print 'Path: '+ newMap
                print stLyr.name

        # 6. zoom to extent and refresh map view
                ext = stLyr.getExtent()
                df.extent = ext
                arcpy.SelectLayerByAttribute_management(stLyr, "CLEAR_SELECTION")
                df.scale = df.scale * 1.1
                arcpy.RefreshActiveView()

        # 7. save MXD as DCA variable name
                mxd.saveACopy(newMap + ".mxd")

        # 8. export map to JPEG, clip output to graphics extent
                arcpy.mapping.ExportToJPEG(mxd, newMap)

        # 9. go to next row in the look up table and repeat steps 5-8
        del DCAcursor, row
        print 'Map export complete.'
except:
    print 'Program failed.'
    del DCAcursor, row    
    tb = sys.exc_info()[2]
    tbinfo = traceback.format_tb(tb)[0]
    pymsg = "PYTHON ERRORS:\nTraceback Info:\n" + tbinfo + "\nError Info:\n     " +        str(sys.exc_type) + ": " + str(sys.exc_value) + "\n"
    msgs = "ARCPY ERRORS:\n" + arcpy.GetMessages(2) + "\n"
    
    arcpy.AddError(msgs)
    arcpy.AddError(pymsg)

    print msgs
    print pymsg
    
    arcpy.AddMessage(arcpy.GetMessages(1))
    print arcpy.GetMessages(1)
